==> haskell-cryptohash-0.11.9-18-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash
version: 0.11.9
id: cryptohash-0.11.9-6k6h6rgW6V32279r46VuUC
key: cryptohash-0.11.9-6k6h6rgW6V32279r46VuUC
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-cryptohash
synopsis: collection of crypto hashes, fast, pure and practical
description:
    DEPRECATED: this library is still fully functional, but please use cryptonite for new projects
    and convert old one to use cryptonite. This is where things are at nowadays.
    .
    A collection of crypto hashes, with a practical incremental and one-pass, pure APIs,
    with performance close to the fastest implementations available in other languages.
    .
    The implementations are made in C with a haskell FFI wrapper that hide the C implementation.
    .
    Simple examples using the unified API:
    .
    > import Crypto.Hash
    >
    > sha1 :: ByteString -> Digest SHA1
    > sha1 = hash
    >
    > hexSha3_512 :: ByteString -> String
    > hexSha3_512 bs = show (hash bs :: Digest SHA3_512)
    .
    Simple examples using the module API:
    .
    > import qualified Crypto.Hash.SHA1 as SHA1
    >
    > main = putStrLn $ show $ SHA1.hash (Data.ByteString.pack [0..255])
    .
    > import qualified Crypto.Hash.SHA3 as SHA3
    >
    > main = putStrLn $ show $ digest
    >   where digest = SHA3.finalize ctx
    >         ctx    = foldl'\'' SHA3.update iCtx (map Data.ByteString.pack [ [1,2,3], [4,5,6] ]
    >         iCtx   = SHA3.init 224
category: Data, Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash Crypto.Hash.Types Crypto.MAC Crypto.Hash.SHA1
    Crypto.Hash.SHA224 Crypto.Hash.SHA256 Crypto.Hash.SHA384
    Crypto.Hash.SHA512 Crypto.Hash.SHA512t Crypto.Hash.SHA3
    Crypto.Hash.MD2 Crypto.Hash.MD4 Crypto.Hash.MD5
    Crypto.Hash.RIPEMD160 Crypto.Hash.Skein256 Crypto.Hash.Skein512
    Crypto.Hash.Tiger Crypto.Hash.Whirlpool Crypto.MAC.HMAC
    Crypto.MAC.SHA3
hidden-modules: Crypto.Hash.Internal
abi: 21c54fdd79c41612b384e1239f2ee7c8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-0.11.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-0.11.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptohash-0.11.9
hs-libraries: HScryptohash-0.11.9-6k6h6rgW6V32279r46VuUC
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 cryptonite-0.22-JqiMjnb5zSBCoWgTNo13Ue
    ghc-prim-0.5.0.0 memory-0.14.3-7kBqUNxMvfU5uu32Wj2xqc
haddock-interfaces: /usr/share/doc/haskell-cryptohash/html/cryptohash.haddock
haddock-html: /usr/share/doc/haskell-cryptohash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-0.11.9-20-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash
version: 0.11.9
id: cryptohash-0.11.9-K1mrjHdP3V8CpgLjXvYwEM
key: cryptohash-0.11.9-K1mrjHdP3V8CpgLjXvYwEM
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-cryptohash
synopsis: collection of crypto hashes, fast, pure and practical
description:
    DEPRECATED: this library is still fully functional, but please use cryptonite for new projects
    and convert old one to use cryptonite. This is where things are at nowadays.
    .
    A collection of crypto hashes, with a practical incremental and one-pass, pure APIs,
    with performance close to the fastest implementations available in other languages.
    .
    The implementations are made in C with a haskell FFI wrapper that hide the C implementation.
    .
    Simple examples using the unified API:
    .
    > import Crypto.Hash
    >
    > sha1 :: ByteString -> Digest SHA1
    > sha1 = hash
    >
    > hexSha3_512 :: ByteString -> String
    > hexSha3_512 bs = show (hash bs :: Digest SHA3_512)
    .
    Simple examples using the module API:
    .
    > import qualified Crypto.Hash.SHA1 as SHA1
    >
    > main = putStrLn $ show $ SHA1.hash (Data.ByteString.pack [0..255])
    .
    > import qualified Crypto.Hash.SHA3 as SHA3
    >
    > main = putStrLn $ show $ digest
    >   where digest = SHA3.finalize ctx
    >         ctx    = foldl'\'' SHA3.update iCtx (map Data.ByteString.pack [ [1,2,3], [4,5,6] ]
    >         iCtx   = SHA3.init 224
category: Data, Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash Crypto.Hash.Types Crypto.MAC Crypto.Hash.SHA1
    Crypto.Hash.SHA224 Crypto.Hash.SHA256 Crypto.Hash.SHA384
    Crypto.Hash.SHA512 Crypto.Hash.SHA512t Crypto.Hash.SHA3
    Crypto.Hash.MD2 Crypto.Hash.MD4 Crypto.Hash.MD5
    Crypto.Hash.RIPEMD160 Crypto.Hash.Skein256 Crypto.Hash.Skein512
    Crypto.Hash.Tiger Crypto.Hash.Whirlpool Crypto.MAC.HMAC
    Crypto.MAC.SHA3
hidden-modules: Crypto.Hash.Internal
abi: ab74f6e0f38dca68d2ea514ffb82af27
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-0.11.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-0.11.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptohash-0.11.9
hs-libraries: HScryptohash-0.11.9-K1mrjHdP3V8CpgLjXvYwEM
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 cryptonite-0.22-DUE2wxQoCnxGJxqhoLxB9Z
    ghc-prim-0.5.0.0 memory-0.14.5-8bv3NC3SoYTKu3JUzoaHbd
haddock-interfaces: /usr/share/doc/haskell-cryptohash/html/cryptohash.haddock
haddock-html: /usr/share/doc/haskell-cryptohash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
